pub fn run_exec(
prompt: &str,
options: &CodexOptions,
) -> Result<CodexRunResult, CodexError>Expand description
Run codex exec with the provided prompt on stdin.
pub fn run_exec(
prompt: &str,
options: &CodexOptions,
) -> Result<CodexRunResult, CodexError>Run codex exec with the provided prompt on stdin.