Module template

Module template 

Template loading and single-pass variable rendering for Humanize.

Enums

TemplateError
Errors that can occur while loading or rendering templates.

Functions

load_and_render
Load and render a template file in one step.
load_and_render_safe
Load and render a template with a fallback string.
load_template
Load a template file from a template root.
render_template
Render a template using single-pass {{VAR}} substitution.
template_dir
Resolve the prompt-template directory from a plugin root.