Template loading and single-pass variable rendering for Humanize.
Enums
- Template
Error - Errors that can occur while loading or rendering templates.
Functions
- load_
and_ render - Load and render a template file in one step.
- load_
and_ render_ safe - Load and render a template with a fallback string.
- load_
template - Load a template file from a template root.
- render_
template - Render a template using single-pass
{{VAR}}substitution. - template_
dir - Resolve the prompt-template directory from a plugin root.